@@ -1,8 +1,9 @@
 import numpy as np
 # import keras
 from tensorflow import keras
-
-from utils.compute_overlap import compute_overlap
+import sys
+sys.path.append("../")
+from ..utils.compute_overlap import compute_overlap
 
 
 class AnchorParameters:
