@@ -16,8 +16,8 @@ limitations under the License.
 
 import keras
 import keras.backend as K
-from utils import anchors as utils_anchors
-import utils_graph
+from .utils import anchors as utils_anchors
+from . import utils_graph
 
 import numpy as np
 import tensorflow as tf
